@@ -1,5 +1,6 @@
 mod half;
 mod num;
+mod num_identity;
 mod num_trampolene;
 mod num_tuple;
 mod number_extensions;
@@ -8,6 +9,7 @@ mod to_signed_clamped;
 
 pub use self::half::*;
 pub use self::num::*;
+pub use self::num_identity::*;
 pub use self::num_trampolene::*;
 pub use self::num_tuple::*;
 pub use self::number_extensions::*;
